@@ -1,4 +1,5 @@
-from typing import Any, Callable, Dict
+from collections.abc import Callable
+from typing import Any
 
 from weaverbird.backends.mongo_translator.steps.absolutevalue import translate_absolutevalue
 from weaverbird.backends.mongo_translator.steps.addmissingdates import translate_addmissingdates
@@ -49,50 +50,50 @@ from weaverbird.backends.mongo_translator.steps.waterfall import translate_water
 # I would like to have a better type for the callable, but I don't know how to do it.
 # each of this function take a particular step as input
 # so it is not possible to use `Dict[str, Callable[[BaseStep], list]]
-mongo_step_translator: Dict[str, Callable[[Any], list]] = {
-    'absolutevalue': translate_absolutevalue,
-    'addmissingdates': translate_addmissingdates,
-    'aggregate': translate_aggregate,
-    'append': translate_append,
-    'argmax': translate_argmax,
-    'argmin': translate_argmin,
-    'comparetext': translate_comparetext,
-    'concatenate': translate_concatenate,
-    'convert': translate_convert,
-    'cumsum': translate_cumsum,
-    'custom': translate_custom,
-    'dateextract': translate_date_extract,
-    'delete': translate_delete,
-    'domain': translate_domain,
-    'duplicate': translate_duplicate,
-    'duration': translate_duration,
-    'evolution': translate_evolution,
-    'fillna': translate_fillna,
-    'filter': translate_filter,
-    'formula': translate_formula,
-    'fromdate': translate_fromdate,
-    'ifthenelse': translate_ifthenelse,  # type: ignore
-    'join': translate_join,
-    'lowercase': translate_lowercase,
-    'movingaverage': translate_moving_average,
-    'percentage': translate_percentage,
-    'pivot': translate_pivot,
-    'rename': translate_rename,
-    'rank': translate_rank,
-    'replace': translate_replace,
-    'rollup': translate_rollup,
-    'select': translate_select,
-    'sort': translate_sort,
-    'split': translate_split,
-    'statistics': translate_statistics,
-    'substring': translate_substring,
-    'text': translate_text,
-    'todate': translate_todate,
-    'totals': translate_totals,
-    'top': translate_top,
-    'trim': translate_trim,
-    'uniquegroups': translate_uniquegroups,
-    'unpivot': translate_unpivot,
-    'uppercase': translate_uppercase,
-    'waterfall': translate_waterfall,
+mongo_step_translator: dict[str, Callable[[Any], list]] = {
+    "absolutevalue": translate_absolutevalue,
+    "addmissingdates": translate_addmissingdates,
+    "aggregate": translate_aggregate,
+    "append": translate_append,
+    "argmax": translate_argmax,
+    "argmin": translate_argmin,
+    "comparetext": translate_comparetext,
+    "concatenate": translate_concatenate,
+    "convert": translate_convert,
+    "cumsum": translate_cumsum,
+    "custom": translate_custom,
+    "dateextract": translate_date_extract,
+    "delete": translate_delete,
+    "domain": translate_domain,
+    "duplicate": translate_duplicate,
+    "duration": translate_duration,
+    "evolution": translate_evolution,
+    "fillna": translate_fillna,
+    "filter": translate_filter,
+    "formula": translate_formula,
+    "fromdate": translate_fromdate,
+    "ifthenelse": translate_ifthenelse,
+    "join": translate_join,
+    "lowercase": translate_lowercase,
+    "movingaverage": translate_moving_average,
+    "percentage": translate_percentage,
+    "pivot": translate_pivot,
+    "rename": translate_rename,
+    "rank": translate_rank,
+    "replace": translate_replace,
+    "rollup": translate_rollup,
+    "select": translate_select,
+    "sort": translate_sort,
+    "split": translate_split,
+    "statistics": translate_statistics,
+    "substring": translate_substring,
+    "text": translate_text,
+    "todate": translate_todate,
+    "totals": translate_totals,
+    "top": translate_top,
+    "trim": translate_trim,
+    "uniquegroups": translate_uniquegroups,
+    "unpivot": translate_unpivot,
+    "uppercase": translate_uppercase,
+    "waterfall": translate_waterfall,
 }
