@@ -1,5 +1,3 @@
-from typing import Dict
-
 from ..types import StepExecutor
 from .absolutevalue import execute_absolutevalue
 from .addmissingdates import execute_addmissingdates
@@ -49,52 +47,52 @@ from .unpivot import execute_unpivot
 from .uppercase import execute_uppercase
 from .waterfall import execute_waterfall
 
-steps_executors: Dict[str, StepExecutor] = {
-    'absolutevalue': execute_absolutevalue,
-    'addmissingdates': execute_addmissingdates,
-    'aggregate': execute_aggregate,
-    'append': execute_append,  # type: ignore
-    'argmax': execute_argmax,
-    'argmin': execute_argmin,
-    'comparetext': execute_comparetext,
-    'concatenate': execute_concatenate,
-    'convert': execute_convert,
-    'cumsum': execute_cumsum,
-    'dateextract': execute_date_extract,
-    'delete': execute_delete,
-    'dissolve': execute_dissolve,
-    'domain': execute_domain,  # type: ignore
-    'duplicate': execute_duplicate,
-    'duration': execute_duration,
-    'evolution': execute_evolution,
-    'fillna': execute_fillna,
-    'filter': execute_filter,
-    'formula': execute_formula,
-    'fromdate': execute_fromdate,
-    'hierarchy': execute_hierarchy,
-    'ifthenelse': execute_ifthenelse,
-    'join': execute_join,  # type: ignore
-    'lowercase': execute_lowercase,
-    'movingaverage': execute_moving_average,
-    'percentage': execute_percentage,
-    'pivot': execute_pivot,
-    'rank': execute_rank,
-    'rename': execute_rename,
-    'replace': execute_replace,
-    'rollup': execute_rollup,
-    'select': execute_select,
-    'simplify': execute_simplify,
-    'sort': execute_sort,
-    'split': execute_split,
-    'statistics': execute_statistics,
-    'substring': execute_substring,
-    'text': execute_text,
-    'todate': execute_todate,
-    'top': execute_top,
-    'totals': execute_totals,
-    'trim': execute_trim,
-    'uniquegroups': execute_uniquegroups,
-    'unpivot': execute_unpivot,
-    'uppercase': execute_uppercase,
-    'waterfall': execute_waterfall,
+steps_executors: dict[str, StepExecutor] = {
+    "absolutevalue": execute_absolutevalue,
+    "addmissingdates": execute_addmissingdates,
+    "aggregate": execute_aggregate,
+    "append": execute_append,  # type: ignore
+    "argmax": execute_argmax,
+    "argmin": execute_argmin,
+    "comparetext": execute_comparetext,
+    "concatenate": execute_concatenate,
+    "convert": execute_convert,
+    "cumsum": execute_cumsum,
+    "dateextract": execute_date_extract,
+    "delete": execute_delete,
+    "dissolve": execute_dissolve,
+    "domain": execute_domain,  # type: ignore
+    "duplicate": execute_duplicate,
+    "duration": execute_duration,
+    "evolution": execute_evolution,
+    "fillna": execute_fillna,
+    "filter": execute_filter,
+    "formula": execute_formula,
+    "fromdate": execute_fromdate,
+    "hierarchy": execute_hierarchy,
+    "ifthenelse": execute_ifthenelse,
+    "join": execute_join,  # type: ignore
+    "lowercase": execute_lowercase,
+    "movingaverage": execute_moving_average,
+    "percentage": execute_percentage,
+    "pivot": execute_pivot,
+    "rank": execute_rank,
+    "rename": execute_rename,
+    "replace": execute_replace,
+    "rollup": execute_rollup,
+    "select": execute_select,
+    "simplify": execute_simplify,
+    "sort": execute_sort,
+    "split": execute_split,
+    "statistics": execute_statistics,
+    "substring": execute_substring,
+    "text": execute_text,
+    "todate": execute_todate,
+    "top": execute_top,
+    "totals": execute_totals,
+    "trim": execute_trim,
+    "uniquegroups": execute_uniquegroups,
+    "unpivot": execute_unpivot,
+    "uppercase": execute_uppercase,
+    "waterfall": execute_waterfall,
 }
