@@ -3,14 +3,13 @@ from typing import TYPE_CHECKING, TypeVar
 
 from pypika import Field, Table, functions
 from pypika.dialects import MySQLQuery
-from pypika.queries import QueryBuilder
-from pypika.terms import LiteralValue, Term
+from pypika.enums import Dialects
+from pypika.terms import Case, Term
 from pypika.utils import format_quotes
 
 from weaverbird.backends.pypika_translator.dialects import SQLDialect
 from weaverbird.backends.pypika_translator.operators import FromDateOp, RegexOp, ToDateOp
 from weaverbird.backends.pypika_translator.translators.base import (
-    DATE_INFO,
     DataTypeMapping,
     SQLTranslator,
     StepContext,
@@ -20,6 +19,8 @@ from weaverbird.pipeline.steps import UnpivotStep
 Self = TypeVar("Self", bound="MySQLTranslator")
 
 if TYPE_CHECKING:
+    from pypika.queries import QueryBuilder
+
     from weaverbird.pipeline.steps import SplitStep
 
 
@@ -42,14 +43,6 @@ class MySQLTranslator(SQLTranslator):
     REGEXP_OP = RegexOp.REGEXP
     TO_DATE_OP = ToDateOp.STR_TO_DATE
 
-    @classmethod
-    def _add_date(
-        cls, *, date_column: Field, add_date_value: int, add_date_unit: DATE_INFO
-    ) -> Term:
-        return LiteralValue(
-            f"DATE_ADD({date_column.name}, INTERVAL {add_date_value} {add_date_unit})"
-        )
-
     @classmethod
     def _build_unpivot_col(
         cls, *, step: "UnpivotStep", quote_char: str | None, secondary_quote_char: str
@@ -74,15 +67,30 @@ class MySQLTranslator(SQLTranslator):
         col_field: Field = Table(prev_step_name)[step.column]
         new_cols = [f"{step.column}_{i + 1}" for i in range(step.number_cols_to_keep)]
 
+        def build_columns():
+            for i in range(step.number_cols_to_keep):
+                yield (
+                    # We need a case, because by default, the nested SubstringIndex will return the
+                    # entire string: -1 (the last part of the split) will be index 0. So we first
+                    # check if the delimiter is even contained in the regex
+                    Case()
+                    .when(
+                        # This is hacky but I couldn't figure another way. This regex ensures that
+                        # the group matches at least i times (i.e., the delimiter is present at
+                        # least n times). The regex is always true for i=0 so kind of unnecessary,
+                        # but having another Case statement for i=0 would be hell
+                        col_field.regexp(f"(({step.delimiter}).*){{{i}}}"),
+                        # https://stackoverflow.com/a/32500349
+                        SubstringIndex(
+                            SubstringIndex(col_field, step.delimiter, i + 1), step.delimiter, -1
+                        ),
+                    )
+                    .else_("")
+                    .as_(new_cols[i])
+                )
+
         query: "QueryBuilder" = self.QUERY_CLS.from_(prev_step_name).select(
-            *columns,
-            *(
-                # https://stackoverflow.com/a/32500349
-                SubstringIndex(
-                    SubstringIndex(col_field, step.delimiter, i + 1), step.delimiter, -1
-                ).as_(new_cols[i])
-                for i in range(step.number_cols_to_keep)
-            ),
+            *columns, *build_columns()
         )
         return StepContext(query, columns + new_cols)
 
@@ -90,6 +98,17 @@ class MySQLTranslator(SQLTranslator):
     def _cast_to_timestamp(value: str | datetime | Field | Term) -> functions.Function:
         return functions.Timestamp(value)
 
+    @classmethod
+    def _add_date(
+        cls, *, target_column: Field, duration: int, unit: str, dialect: Dialects | None = None
+    ) -> Term:
+        return super()._add_date(
+            target_column=target_column,
+            duration=duration,
+            unit=unit,
+            dialect=dialect or Dialects.MYSQL,
+        )
+
 
 SQLTranslator.register(MySQLTranslator)
 
