@@ -1,7 +1,6 @@
 from __future__ import annotations
 
 import copy
-from typing import Dict, List, Optional
 
 from pydantic import BaseModel
 
@@ -12,21 +11,21 @@ class MetadataError(Exception):
 
 class ColumnMetadata(BaseModel):
     name: str
-    original_name: Optional[str]
+    original_name: str | None
     type: str
-    original_type: Optional[str]
-    alias: Optional[str]
+    original_type: str | None
+    alias: str | None
 
-    delete: Optional[bool] = False
+    delete: bool | None = False
 
     def __init__(self, **kwargs):
         super().__init__(**kwargs)
-        if 'name' not in kwargs or 'type' not in kwargs:
-            raise MetadataError('name is required')
-        self.name: str = kwargs['name'].upper()
-        self.original_name: str = kwargs['name']
-        self.type: str = kwargs['type'].upper()
-        self.original_type: str = kwargs['type']
+        if "name" not in kwargs or "type" not in kwargs:
+            raise MetadataError("name is required")
+        self.name: str = kwargs["name"].upper()
+        self.original_name: str = kwargs["name"]
+        self.type: str = kwargs["type"].upper()
+        self.original_type: str = kwargs["type"]
 
     def __eq__(self, other):
         return self.name == other.name and self.type == other.type
@@ -62,18 +61,18 @@ class ColumnMetadata(BaseModel):
 
 class TableMetadata(BaseModel):
     name: str
-    original_name: Optional[str]
+    original_name: str | None
 
-    delete: Optional[bool] = False
+    delete: bool | None = False
 
-    columns: Optional[Dict[str, ColumnMetadata]] = {}
+    columns: dict[str, ColumnMetadata] | None = {}
 
     def __init__(self, **kwargs):
         super().__init__(**kwargs)
-        if 'name' not in kwargs:
-            raise MetadataError('Name is required')
-        self.name: str = kwargs['name'].upper()
-        self.original_name: str = kwargs['name']
+        if "name" not in kwargs:
+            raise MetadataError("Name is required")
+        self.name: str = kwargs["name"].upper()
+        self.original_name: str = kwargs["name"]
 
     def __eq__(self, other):
         return self.name == other.name
@@ -84,7 +83,7 @@ class TableMetadata(BaseModel):
 
     def retrieve_column_by_column_name(
         self, column_name: str, deleted: bool = False
-    ) -> Optional[ColumnMetadata]:
+    ) -> ColumnMetadata | None:
         c_name = column_name.upper()
         if c_name in self.columns and (
             (deleted and self.columns[c_name].is_deleted()) or not self.columns[c_name].is_deleted()
@@ -92,8 +91,8 @@ class TableMetadata(BaseModel):
             return self.columns[c_name]
         return None
 
-    def retrieve_columns(self, deleted: bool = False) -> Dict[str, ColumnMetadata]:
-        l: Dict[str, ColumnMetadata] = {}
+    def retrieve_columns(self, deleted: bool = False) -> dict[str, ColumnMetadata]:
+        l: dict[str, ColumnMetadata] = {}
         for c_name in self.columns:
             if (deleted and self.columns[c_name].is_deleted()) or not self.columns[
                 c_name
@@ -103,9 +102,9 @@ class TableMetadata(BaseModel):
 
     def retrieve_column_by_type(
         self, column_type: str, deleted: bool = False
-    ) -> Dict[str, ColumnMetadata]:
+    ) -> dict[str, ColumnMetadata]:
         c_type = column_type.upper()
-        result: Dict[str, ColumnMetadata] = {}
+        result: dict[str, ColumnMetadata] = {}
         for c_name, column in self.columns:
             if (
                 column.type == c_type
@@ -120,19 +119,19 @@ class TableMetadata(BaseModel):
         self.columns[c_name] = column
         return self
 
-    def add_columns_o(self, columns: List[ColumnMetadata]) -> TableMetadata:
+    def add_columns_o(self, columns: list[ColumnMetadata]) -> TableMetadata:
         for c in columns:
             self.add_column_o(column=c)
         return self
 
     def add_column(
-        self, column_name: str, column_type: str, alias: Optional[str] = None
+        self, column_name: str, column_type: str, alias: str | None = None
     ) -> TableMetadata:
         c = ColumnMetadata(name=column_name, type=column_type, alias=alias)
         self.add_column_o(c)
         return self
 
-    def add_columns(self, columns: Dict[str, str]) -> TableMetadata:
+    def add_columns(self, columns: dict[str, str]) -> TableMetadata:
         for k, v in columns.items():
             self.add_column(column_name=k, column_type=v)
         return self
@@ -140,7 +139,7 @@ class TableMetadata(BaseModel):
     def update_column_name(self, column_name: str, dest_column_name: str) -> TableMetadata:
         c_name = column_name.upper()
         if c_name not in self.columns:
-            raise MetadataError(f'Error to update column {c_name}({column_name}), column not exist')
+            raise MetadataError(f"Error to update column {c_name}({column_name}), column not exist")
         result = self.columns[c_name].update_name(dest_column_name)
         del self.columns[c_name]
         self.columns[result.name] = result
@@ -149,7 +148,7 @@ class TableMetadata(BaseModel):
     def update_column_type(self, column_name: str, dest_column_type: str) -> ColumnMetadata:
         c_name = column_name.upper()
         if c_name not in self.columns:
-            raise MetadataError(f'Error to update column {c_name}({column_name}), column not exist')
+            raise MetadataError(f"Error to update column {c_name}({column_name}), column not exist")
         self.columns[c_name] = self.columns[c_name].update_type(dest_column_type)
         return self.columns[c_name]
 
@@ -157,7 +156,7 @@ class TableMetadata(BaseModel):
         c_name = column_name.upper()
         if c_name not in self.columns:
             raise MetadataError(
-                f'Error updating column {c_name}({column_name}), column does not exist'
+                f"Error updating column {c_name}({column_name}), column does not exist"
             )
         self.columns[c_name] = self.columns[c_name].update_alias(alias)
         return self
@@ -168,12 +167,12 @@ class TableMetadata(BaseModel):
             self.columns[c_name].remove()
         # else warn that column does not exist
 
-    def remove_columns(self, columns_name: List[str]) -> int:
+    def remove_columns(self, columns_name: list[str]) -> int:
         i = 0
         for name in columns_name:
             c_name = name.upper()
             if c_name not in self.columns:
-                raise MetadataError(f'Error to delete column {c_name}({name}), column not exist')
+                raise MetadataError(f"Error to delete column {c_name}({name}), column not exist")
             self.columns[c_name].remove()
             i += 1
         return i
@@ -189,7 +188,7 @@ class TableMetadata(BaseModel):
 
     def remove_column_alias(self, column_name: str) -> TableMetadata:
         if column_name not in self.columns:
-            raise MetadataError(f'Error updating column {column_name}), column does not exist')
+            raise MetadataError(f"Error updating column {column_name}), column does not exist")
         self.columns[column_name].remove_alias()
         return self
 
@@ -198,35 +197,35 @@ class TableMetadata(BaseModel):
 
 
 class SqlQueryMetadataManager(BaseModel):
-    tables: Optional[Dict[str, TableMetadata]]
+    tables: dict[str, TableMetadata] | None
 
     def __init__(self, **kwargs):
         super().__init__(**kwargs)
 
-        self.tables = {'__INTERNAL__': TableMetadata(name='__INTERNAL__')}
-        if 'tables_metadata' in kwargs:
+        self.tables = {"__INTERNAL__": TableMetadata(name="__INTERNAL__")}
+        if "tables_metadata" in kwargs:
             first = True
-            for table_name in kwargs['tables_metadata']:
+            for table_name in kwargs["tables_metadata"]:
                 table = self.create_table(table_name)
-                for column in kwargs['tables_metadata'][table_name]:
-                    table.add_column(column, kwargs['tables_metadata'][table_name][column])
+                for column in kwargs["tables_metadata"][table_name]:
+                    table.add_column(column, kwargs["tables_metadata"][table_name][column])
                 if first:
                     self.define_as_metadata(table_name)
                     first = False
 
     def _check_name(self, name) -> bool:
-        if name == '__INTERNAL__':
-            raise MetadataError('Table __INTERNAL__ is reserved')
+        if name == "__INTERNAL__":
+            raise MetadataError("Table __INTERNAL__ is reserved")
         return True
 
     def define_as_metadata(self, table_name: str) -> SqlQueryMetadataManager:
         t_name = table_name.upper()
         if t_name not in self.tables and self._check_name(t_name):
             raise MetadataError(
-                f'Impossible to define table {t_name}({table_name}) - Table does not exist'
+                f"Impossible to define table {t_name}({table_name}) - Table does not exist"
             )
-        self.tables['__INTERNAL__'] = copy.deepcopy(self.tables[t_name])
-        self.tables['__INTERNAL__'].original_name = table_name
+        self.tables["__INTERNAL__"] = copy.deepcopy(self.tables[t_name])
+        self.tables["__INTERNAL__"].original_name = table_name
         return self
 
     def create_table(self, table_name: str) -> TableMetadata:
@@ -244,7 +243,7 @@ class SqlQueryMetadataManager(BaseModel):
         t_name = table_name.upper()
         if t_name not in self.tables and self._check_name(t_name):
             raise MetadataError(
-                f'Impossible to remove table {t_name}({table_name}) - Table does not exist'
+                f"Impossible to remove table {t_name}({table_name}) - Table does not exist"
             )
         self.tables[t_name] = self.tables[t_name].remove()
         return self
@@ -256,7 +255,7 @@ class SqlQueryMetadataManager(BaseModel):
     def update_table(self, table_name: str, dest_table_name: str) -> SqlQueryMetadataManager:
         t_name = table_name.upper()
         if t_name not in self.tables and self._check_name(t_name):
-            raise MetadataError(f'Table {t_name}({table_name}) not exist')
+            raise MetadataError(f"Table {t_name}({table_name}) not exist")
         result = self.tables[t_name].update_name(dest_table_name)
         del self.tables[t_name]
         self.tables[result.name] = result
@@ -280,40 +279,40 @@ class SqlQueryMetadataManager(BaseModel):
         jt_name: str = join_table.upper()
         if jt_name not in self.tables:
             raise MetadataError(
-                f'Impossible to merge table {jt_name}({join_table}) - Table not exist'
+                f"Impossible to merge table {jt_name}({join_table}) - Table not exist"
             )
-        self.create_table(table_name='__TEMP_JOIN__')
+        self.create_table(table_name="__TEMP_JOIN__")
 
         for cname in self.retrieve_query_metadata_columns():
             self.add_table_column(
-                table_name='__TEMP_JOIN__',
-                column_name=f'{left_query_name}.{cname}',
+                table_name="__TEMP_JOIN__",
+                column_name=f"{left_query_name}.{cname}",
                 column_type=self.retrieve_query_metadata_column_by_name(cname).type,
-                alias=f'{cname}_LEFT',
+                alias=f"{cname}_LEFT",
             )
-        self.define_as_metadata(table_name='__TEMP_JOIN__')
+        self.define_as_metadata(table_name="__TEMP_JOIN__")
 
         for cname in self.tables[jt_name].columns:
             self.add_query_metadata_column(
-                column_name=f'{jt_name}.{cname}',
+                column_name=f"{jt_name}.{cname}",
                 column_type=self.retrieve_column_by_name(
                     table_name=jt_name, column_name=cname
                 ).type,
-                alias=f'{cname}_RIGHT',
+                alias=f"{cname}_RIGHT",
             )
 
         return self
 
-    def append_queries_metadata(self, unioned_tables: List[str]) -> SqlQueryMetadataManager:
+    def append_queries_metadata(self, unioned_tables: list[str]) -> SqlQueryMetadataManager:
         try:
             all_columns = [self.retrieve_columns_as_list(t) for t in unioned_tables]
             all_columns.sort(key=len)
-            max_column_number = max([len(cl) for cl in all_columns])
+            max_column_number = max(len(cl) for cl in all_columns)
         except ValueError:
-            raise MetadataError('Impossible to append tables - Table does not exist')
+            raise MetadataError("Impossible to append tables - Table does not exist")
 
-        new_table = TableMetadata(name='__INTERNAL__')
-        new_table.original_name = self.tables['__INTERNAL__'].original_name
+        new_table = TableMetadata(name="__INTERNAL__")
+        new_table.original_name = self.tables["__INTERNAL__"].original_name
         new_table.columns = self.retrieve_query_metadata_columns()
         if len(new_table.columns) < max_column_number:
             index_cols_to_add = range(len(new_table.columns), max_column_number)
@@ -321,38 +320,38 @@ class SqlQueryMetadataManager(BaseModel):
                 for index in index_cols_to_add:
                     if index < len(cols):
                         new_table.add_column(
-                            column_name=f'NULL AS {cols[index]}', column_type='UNDEFINED'
+                            column_name=f"NULL AS {cols[index]}", column_type="UNDEFINED"
                         )
-        self.tables['__INTERNAL__'] = new_table
+        self.tables["__INTERNAL__"] = new_table
         return self
 
     def add_table_column(
-        self, table_name: str, column_name: str, column_type: str, alias: Optional[str] = None
+        self, table_name: str, column_name: str, column_type: str, alias: str | None = None
     ) -> TableMetadata:
         t_name = table_name.upper()
         if t_name not in self.tables:
             raise MetadataError(
-                f'Impossible to update column name, table {t_name}({table_name}) not exist'
+                f"Impossible to update column name, table {t_name}({table_name}) not exist"
             )
         self.tables[t_name] = self.tables[t_name].add_column(column_name, column_type, alias)
         return self.tables[t_name]
 
-    def add_table_columns_from_dict(self, table_name: str, columns_dict: Dict[str, str]):
+    def add_table_columns_from_dict(self, table_name: str, columns_dict: dict[str, str]):
         t_name = table_name.upper()
         if t_name not in self.tables:
             raise MetadataError(
-                f'Impossible to update column name, table {t_name}({table_name}) does not exist'
+                f"Impossible to update column name, table {t_name}({table_name}) does not exist"
             )
         for name, type in columns_dict.items():
             self.tables[t_name] = self.tables[t_name].add_column(name, type)
 
     def add_query_metadata_column(
-        self, column_name: str, column_type: str, alias: Optional[str] = None
+        self, column_name: str, column_type: str, alias: str | None = None
     ) -> TableMetadata:
-        return self.add_table_column('__INTERNAL__', column_name, column_type, alias)
+        return self.add_table_column("__INTERNAL__", column_name, column_type, alias)
 
-    def add_query_metadata_columns(self, columns: Dict[str, str]) -> TableMetadata:
-        return self.add_table_columns_from_dict('__INTERNAL__', columns)
+    def add_query_metadata_columns(self, columns: dict[str, str]) -> TableMetadata:
+        return self.add_table_columns_from_dict("__INTERNAL__", columns)
 
     def update_column_name(
         self, table_name: str, column_name: str, dest_column_name: str
@@ -360,7 +359,7 @@ class SqlQueryMetadataManager(BaseModel):
         t_name = table_name.upper()
         if t_name not in self.tables:
             raise MetadataError(
-                f'Impossible to update column name, table {t_name}({table_name}) not exist'
+                f"Impossible to update column name, table {t_name}({table_name}) not exist"
             )
         self.tables[t_name] = self.tables[t_name].update_column_name(column_name, dest_column_name)
         return self.tables[t_name]
@@ -369,7 +368,7 @@ class SqlQueryMetadataManager(BaseModel):
         t_name = table_name.upper()
         if t_name not in self.tables:
             raise MetadataError(
-                f'Impossible to update column\'s alias, table {t_name}({table_name}) does not exist'
+                f"Impossible to update column's alias, table {t_name}({table_name}) does not exist"
             )
         self.tables[t_name] = self.tables[t_name].update_column_alias(column_name, alias)
         return self.tables[t_name]
@@ -377,7 +376,7 @@ class SqlQueryMetadataManager(BaseModel):
     def remove_column_alias(self, table_name: str, column_name: str) -> TableMetadata:
         if table_name not in self.tables:
             raise MetadataError(
-                f'Impossible to remove column\'s alias, table {table_name} does not exist'
+                f"Impossible to remove column's alias, table {table_name} does not exist"
             )
         self.tables[table_name] = self.tables[table_name].remove_column_alias(column_name)
         return self.tables[table_name]
@@ -385,12 +384,12 @@ class SqlQueryMetadataManager(BaseModel):
     def update_query_metadata_column_name(
         self, column_name: str, dest_column_name: str
     ) -> TableMetadata:
-        self.update_column_name('__INTERNAL__', column_name, dest_column_name)
-        return self.retrieve_table('__INTERNAL__')
+        self.update_column_name("__INTERNAL__", column_name, dest_column_name)
+        return self.retrieve_table("__INTERNAL__")
 
     def update_query_metadata_column_alias(self, column_name: str, alias: str):
-        self.update_column_alias('__INTERNAL__', column_name, alias)
-        return self.retrieve_table('__INTERNAL__')
+        self.update_column_alias("__INTERNAL__", column_name, alias)
+        return self.retrieve_table("__INTERNAL__")
 
     def update_column_type(
         self, table_name: str, column_name: str, dest_column_type: str
@@ -398,56 +397,56 @@ class SqlQueryMetadataManager(BaseModel):
         t_name = table_name.upper()
         if t_name not in self.tables:
             raise MetadataError(
-                f'Impossible to update column type, table {t_name}({table_name}) not exist'
+                f"Impossible to update column type, table {t_name}({table_name}) not exist"
             )
         self.tables[t_name].update_column_type(column_name, dest_column_type)
-        return self.retrieve_table('__INTERNAL__')
+        return self.retrieve_table("__INTERNAL__")
 
     def update_query_metadata_column_type(
         self, column_name: str, dest_column_type: str
     ) -> TableMetadata:
-        self.update_column_type('__INTERNAL__', column_name, dest_column_type)
-        return self.retrieve_table('__INTERNAL__')
+        self.update_column_type("__INTERNAL__", column_name, dest_column_type)
+        return self.retrieve_table("__INTERNAL__")
 
     def remove_table_column(self, table_name: str, column_name: str) -> TableMetadata:
         t_name = table_name.upper()
         if t_name not in self.tables:
             raise MetadataError(
-                f'Impossible to delete column, table {t_name}({table_name}) does not exist'
+                f"Impossible to delete column, table {t_name}({table_name}) does not exist"
             )
         self.tables[t_name].remove_column(column_name)
         return self.tables[t_name]
 
     def remove_query_metadata_column(self, column_name: str) -> TableMetadata:
-        return self.remove_table_column('__INTERNAL__', column_name)
+        return self.remove_table_column("__INTERNAL__", column_name)
 
     def remove_query_metadata_column_alias(self, column_name: str) -> TableMetadata:
-        return self.remove_column_alias('__INTERNAL__', column_name)
+        return self.remove_column_alias("__INTERNAL__", column_name)
 
-    def remove_table_columns(self, table_name: str, columns_name: List[str]) -> TableMetadata:
+    def remove_table_columns(self, table_name: str, columns_name: list[str]) -> TableMetadata:
         t_name = table_name.upper()
         if t_name not in self.tables:
             raise MetadataError(
-                f'Impossible to delete column, table {t_name}({table_name}) does not exist'
+                f"Impossible to delete column, table {t_name}({table_name}) does not exist"
             )
         self.tables[t_name].remove_columns(columns_name)
         return self.tables[t_name]
 
-    def remove_query_metadata_columns(self, columns_name: List[str]) -> TableMetadata:
-        return self.remove_table_columns('__INTERNAL__', columns_name)
+    def remove_query_metadata_columns(self, columns_name: list[str]) -> TableMetadata:
+        return self.remove_table_columns("__INTERNAL__", columns_name)
 
     def remove_table_all_columns(self, table_name: str) -> int:
         t_name = table_name.upper()
         if t_name not in self.tables:
             raise MetadataError(
-                f'Impossible to delete column, table {t_name}({table_name}) does not exist'
+                f"Impossible to delete column, table {t_name}({table_name}) does not exist"
             )
         return self.tables[t_name].remove_all_columns()
 
     def remove_query_metadata_all_columns(self) -> int:
-        return self.remove_table_all_columns('__INTERNAL__')
+        return self.remove_table_all_columns("__INTERNAL__")
 
-    def retrieve_table(self, table_name: str, deleted: bool = False) -> Optional[TableMetadata]:
+    def retrieve_table(self, table_name: str, deleted: bool = False) -> TableMetadata | None:
         t_name = table_name.upper()
         if t_name in self.tables and (
             (deleted and self.tables[t_name].is_deleted()) or not self.tables[t_name].is_deleted()
@@ -456,61 +455,61 @@ class SqlQueryMetadataManager(BaseModel):
         return None
 
     def retrieve_query_metadata(self) -> TableMetadata:
-        return self.retrieve_table('__INTERNAL__')
+        return self.retrieve_table("__INTERNAL__")
 
     def retrieve_table_columns(
         self, table_name: str, deleted: bool = False
-    ) -> Dict[str, ColumnMetadata]:
+    ) -> dict[str, ColumnMetadata]:
         t_name = table_name.upper()
         if t_name not in self.tables:
             raise MetadataError(
-                f'Impossible to retrieve column for table {t_name}({table_name}) - Table does not exist'
+                f"Impossible to retrieve column for table {t_name}({table_name}) - Table does not exist"
             )
         return self.tables[t_name].retrieve_columns(deleted)
 
-    def retrieve_query_metadata_columns(self, deleted: bool = False) -> Dict[str, ColumnMetadata]:
-        return self.retrieve_table_columns('__INTERNAL__', deleted)
+    def retrieve_query_metadata_columns(self, deleted: bool = False) -> dict[str, ColumnMetadata]:
+        return self.retrieve_table_columns("__INTERNAL__", deleted)
 
     def retrieve_columns_as_list(
-        self, table_name: str, columns_filter: List[str] = None, deleted: bool = False
-    ) -> List[str]:
+        self, table_name: str, columns_filter: list[str] = None, deleted: bool = False
+    ) -> list[str]:
         columns = self.retrieve_table_columns(table_name, deleted)
         filter_format = []
         if columns_filter is not None:
             filter_format = [f.upper() for f in columns_filter]
-        result: List[str] = []
+        result: list[str] = []
         for name, column_metadata in columns.items():
             if name not in filter_format:
-                alias = getattr(column_metadata, 'alias')
+                alias = getattr(column_metadata, "alias")
                 if alias:
-                    result.append(f'{name} AS {alias}')
+                    result.append(f"{name} AS {alias}")
                 else:
                     result.append(name)
         return result
 
     def retrieve_columns_as_str(
-        self, table_name: str, columns_filter: List[str] = None, deleted: bool = False
+        self, table_name: str, columns_filter: list[str] = None, deleted: bool = False
     ) -> str:
-        return ', '.join(
+        return ", ".join(
             self.retrieve_columns_as_list(
                 table_name, columns_filter=columns_filter, deleted=deleted
             )
         )
 
     def retrieve_query_metadata_columns_as_str(
-        self, columns_filter: List[str] = None, deleted: bool = False
+        self, columns_filter: list[str] = None, deleted: bool = False
     ) -> str:
-        return ', '.join(
+        return ", ".join(
             self.retrieve_columns_as_list(
-                '__INTERNAL__', columns_filter=columns_filter, deleted=deleted
+                "__INTERNAL__", columns_filter=columns_filter, deleted=deleted
             )
         )
 
     def retrieve_query_metadata_columns_as_list(
-        self, columns_filter: List[str] = None, deleted: bool = False
-    ) -> List[str]:
+        self, columns_filter: list[str] = None, deleted: bool = False
+    ) -> list[str]:
         return self.retrieve_columns_as_list(
-            '__INTERNAL__', columns_filter=columns_filter, deleted=deleted
+            "__INTERNAL__", columns_filter=columns_filter, deleted=deleted
         )
 
     def retrieve_column_by_name(
@@ -519,35 +518,35 @@ class SqlQueryMetadataManager(BaseModel):
         t_name = table_name.upper()
         if t_name not in self.tables:
             raise MetadataError(
-                f'Impossible to retrieve column for table {t_name}({table_name}) - Table does not exist'
+                f"Impossible to retrieve column for table {t_name}({table_name}) - Table does not exist"
             )
         return self.tables[t_name].retrieve_column_by_column_name(column_name, deleted)
 
     def retrieve_query_metadata_column_by_name(self, column_name: str) -> ColumnMetadata:
-        return self.retrieve_column_by_name('__INTERNAL__', column_name)
+        return self.retrieve_column_by_name("__INTERNAL__", column_name)
 
     def retrieve_query_metadata_column_type_by_name(self, column_name: str) -> str:
         return (
-            self.retrieve_column_by_name('__INTERNAL__', column_name).type
-            if hasattr(self.retrieve_column_by_name('__INTERNAL__', column_name), 'type')
-            else 'UNDEFINED'
+            self.retrieve_column_by_name("__INTERNAL__", column_name).type
+            if hasattr(self.retrieve_column_by_name("__INTERNAL__", column_name), "type")
+            else "UNDEFINED"
         )
 
     def retrieve_columns_by_type(
         self, table_name: str, column_type: str, deleted: bool = False
-    ) -> Dict[str, ColumnMetadata]:
+    ) -> dict[str, ColumnMetadata]:
         t_name = table_name.upper()
         if t_name not in self.tables:
             raise MetadataError(
-                f'Impossible to retrieve column for table {t_name}({table_name}) - Table does not exist'
+                f"Impossible to retrieve column for table {t_name}({table_name}) - Table does not exist"
             )
         return self.tables[t_name].retrieve_column_by_type(column_type, deleted)
 
-    def retrieve_query_metadata_column_by_type(self, column_type: str) -> Dict[str, ColumnMetadata]:
-        return self.retrieve_columns_by_type('__INTERNAL__', column_type)
+    def retrieve_query_metadata_column_by_type(self, column_type: str) -> dict[str, ColumnMetadata]:
+        return self.retrieve_columns_by_type("__INTERNAL__", column_type)
 
-    def cast_column_to_string(self, columns: Dict[str, ColumnMetadata]):
-        return ', '.join([cname for cname, column in columns])
+    def cast_column_to_string(self, columns: dict[str, ColumnMetadata]):
+        return ", ".join([cname for cname, column in columns])
 
     def update_query_metadata_column_names_with_alias(self):
         for col in self.retrieve_query_metadata_columns().values():
@@ -557,13 +556,13 @@ class SqlQueryMetadataManager(BaseModel):
                     dest_column_name=col.alias,
                 )
                 self.remove_query_metadata_column_alias(col.alias)
-        return self.retrieve_table('__INTERNAL__')
+        return self.retrieve_table("__INTERNAL__")
 
     def rename_union_columns(self):
         union_columns = self.retrieve_query_metadata_columns()
         [
-            self.update_query_metadata_column_name(cname, cname.split(' ')[-1])
+            self.update_query_metadata_column_name(cname, cname.split(" ")[-1])
             for cname in union_columns.keys()
-            if 'NULL' in cname
+            if "NULL" in cname
         ]
         return self
