@@ -25,28 +25,28 @@ def translate_text(
     subcall_from_other_pipeline_count: int = None,
     sql_dialect: SQLDialect = None,
 ) -> SQLQuery:
-    query_name = f'TEXT_STEP_{index}'
+    query_name = f"TEXT_STEP_{index}"
     log.debug(
-        '############################################################'
-        f'query_name: {query_name}\n'
-        '------------------------------------------------------------'
-        f'step.text: {step.text}\n'
-        f'step.new_column: {step.new_column}\n'
-        f'query.transformed_query: {query.transformed_query}\n'
-        f'query.metadata_manager.query_metadata: {query.metadata_manager.retrieve_query_metadata()}\n'
+        "############################################################"
+        f"query_name: {query_name}\n"
+        "------------------------------------------------------------"
+        f"step.text: {step.text}\n"
+        f"step.new_column: {step.new_column}\n"
+        f"query.transformed_query: {query.transformed_query}\n"
+        f"query.metadata_manager.query_metadata: {query.metadata_manager.retrieve_query_metadata()}\n"
     )
 
     completed_fields = query.metadata_manager.retrieve_query_metadata_columns_as_str()
     renamed_fields = f"""'{step.text}' AS {step.new_column} """
     if completed_fields:
-        renamed_fields = f', {renamed_fields}'
+        renamed_fields = f", {renamed_fields}"
     transformed_query = (
         f"""{query.transformed_query}, {query_name} AS"""
         f""" (SELECT {completed_fields}{renamed_fields}"""
         f"""FROM {query.query_name})"""
     )
 
-    query.metadata_manager.add_query_metadata_column(step.new_column, 'text')
+    query.metadata_manager.add_query_metadata_column(step.new_column, "text")
 
     new_query = SQLQuery(
         query_name=query_name,
@@ -58,9 +58,9 @@ def translate_text(
     )
 
     log.debug(
-        '------------------------------------------------------------'
-        f'SQLquery: {new_query.transformed_query}'
-        '############################################################'
+        "------------------------------------------------------------"
+        f"SQLquery: {new_query.transformed_query}"
+        "############################################################"
     )
 
     return new_query
