@@ -1,5 +1,5 @@
+from collections.abc import Sequence
 from distutils import log
-from typing import List, Sequence
 
 from weaverbird.backends.sql_translator.metadata import ColumnMetadata, SqlQueryMetadataManager
 from weaverbird.backends.sql_translator.steps.utils.query_transformation import (
@@ -20,8 +20,8 @@ from weaverbird.pipeline.types import ColumnName
 from weaverbird.utils.iter import combinations
 
 
-def make_totals_query(step: TotalsStep, parent_query: SQLQuery) -> (str, List[ColumnMetadata]):
-    def select_total_dimensions(total_dimensions: List[TotalDimension]) -> List[ColumnMetadata]:
+def make_totals_query(step: TotalsStep, parent_query: SQLQuery) -> (str, list[ColumnMetadata]):
+    def select_total_dimensions(total_dimensions: list[TotalDimension]) -> list[ColumnMetadata]:
         selects = []
         for dimension in total_dimensions:
             selects.append(
@@ -37,29 +37,29 @@ def make_totals_query(step: TotalsStep, parent_query: SQLQuery) -> (str, List[Co
             )
         return selects
 
-    def select_aggregate(aggregations: Sequence[Aggregation]) -> List[ColumnMetadata]:
+    def select_aggregate(aggregations: Sequence[Aggregation]) -> list[ColumnMetadata]:
         aggregated_cols = []
         for aggregation in [
             aggregation
             for aggregation in aggregations
-            if aggregation.agg_function not in ['first', 'last']
+            if aggregation.agg_function not in ["first", "last"]
         ]:
             for col, new_col in zip(aggregation.columns, aggregation.new_columns):
-                if aggregation.agg_function == 'count distinct':
+                if aggregation.agg_function == "count distinct":
                     aggregated_cols.append(
-                        ColumnMetadata(name=f'COUNT(DISTINCT {col})', alias=new_col, type='FLOAT')
+                        ColumnMetadata(name=f"COUNT(DISTINCT {col})", alias=new_col, type="FLOAT")
                     )
                 else:
                     aggregated_cols.append(
                         ColumnMetadata(
-                            name=f'{aggregation.agg_function.upper()}({col})',
+                            name=f"{aggregation.agg_function.upper()}({col})",
                             alias=new_col,
-                            type='FLOAT',
+                            type="FLOAT",
                         )
                     )
         return aggregated_cols
 
-    def with_alias(selects: List[ColumnMetadata]) -> List[str]:
+    def with_alias(selects: list[ColumnMetadata]) -> list[str]:
         selects_with_alias = []
         for select in selects:
             select_str = select.original_name
@@ -68,9 +68,9 @@ def make_totals_query(step: TotalsStep, parent_query: SQLQuery) -> (str, List[Co
             selects_with_alias.append(select_str)
         return selects_with_alias
 
-    total_dimensions: List[ColumnName] = list(map(lambda x: x.total_column, step.total_dimensions))
+    total_dimensions: list[ColumnName] = list(map(lambda x: x.total_column, step.total_dimensions))
 
-    selects: List[ColumnMetadata] = (
+    selects: list[ColumnMetadata] = (
         select_total_dimensions(step.total_dimensions)
         + select_aggregate(step.aggregations)
         + [
@@ -86,9 +86,9 @@ def make_totals_query(step: TotalsStep, parent_query: SQLQuery) -> (str, List[Co
 
     group_sets = []
     for combination in combinations(total_dimensions):
-        group_sets.append('(' + ', '.join(combination) + ')')
-    group_sets.append('()')
-    group_by = step.groups + ['GROUPING SETS(' + (', '.join(group_sets)) + ')']
+        group_sets.append("(" + ", ".join(combination) + ")")
+    group_sets.append("()")
+    group_by = step.groups + ["GROUPING SETS(" + (", ".join(group_sets)) + ")"]
 
     query = f"""SELECT {', '.join(with_alias(selects))} FROM {parent_query.query_name} GROUP BY {', '.join(group_by)}"""
 
@@ -106,15 +106,15 @@ def translate_totals(
     subcall_from_other_pipeline_count: int = None,
     sql_dialect: SQLDialect = None,
 ) -> SQLQuery:
-    query_name = f'TOTALS_STEP_{index}'
+    query_name = f"TOTALS_STEP_{index}"
 
     log.debug(
-        '############################################################'
-        f'query_name: {query_name}\n'
-        '------------------------------------------------------------'
-        f'step: {step}\n'
-        f'query.transformed_query: {query.transformed_query}\n'
-        f'query.metadata_manager.query_metadata: {query.metadata_manager.retrieve_query_metadata()}\n'
+        "############################################################"
+        f"query_name: {query_name}\n"
+        "------------------------------------------------------------"
+        f"step: {step}\n"
+        f"query.transformed_query: {query.transformed_query}\n"
+        f"query.metadata_manager.query_metadata: {query.metadata_manager.retrieve_query_metadata()}\n"
     )
 
     sql_query, selects = make_totals_query(step, query)
@@ -135,9 +135,9 @@ def translate_totals(
         new_query.metadata_manager.retrieve_query_metadata_columns(), query_name
     )
     log.debug(
-        '------------------------------------------------------------'
-        f'SQLquery: {new_query.transformed_query}'
-        '############################################################'
+        "------------------------------------------------------------"
+        f"SQLquery: {new_query.transformed_query}"
+        "############################################################"
     )
 
     return new_query
