@@ -1,4 +1,4 @@
-from typing import List, Literal, Union
+from typing import Literal
 
 from weaverbird.pipeline.steps.utils.base import BaseStep
 from weaverbird.pipeline.steps.utils.render_variables import StepWithVariablesMixin
@@ -6,10 +6,10 @@ from weaverbird.pipeline.types import ColumnName, TemplatedVariable
 
 
 class ArgmaxStep(BaseStep):
-    name: Literal['argmax'] = 'argmax'
+    name: Literal["argmax"] = "argmax"
     column: ColumnName
-    groups: List[str] = []
+    groups: list[str] = []
 
 
 class ArgmaxStepWithVariable(ArgmaxStep, StepWithVariablesMixin):
-    groups: Union[TemplatedVariable, List[TemplatedVariable]]
+    groups: TemplatedVariable | list[TemplatedVariable]
