@@ -1,4 +1,4 @@
-from typing import List, Literal, Union
+from typing import Literal
 
 from pydantic import Field
 
@@ -8,11 +8,11 @@ from weaverbird.pipeline.types import ColumnName, TemplatedVariable
 
 
 class ConcatenateStep(BaseStep):
-    name: Literal['concatenate'] = 'concatenate'
-    columns: List[ColumnName] = Field(..., min_items=2)
+    name: Literal["concatenate"] = "concatenate"
+    columns: list[ColumnName] = Field(..., min_items=2)
     separator: str
     new_column_name: ColumnName
 
 
 class ConcatenateStepWithVariable(ConcatenateStep, StepWithVariablesMixin):
-    columns: Union[TemplatedVariable, List[TemplatedVariable]]
+    columns: TemplatedVariable | list[TemplatedVariable]
