@@ -1,4 +1,4 @@
-from typing import Any, List, Literal
+from typing import Any, Literal
 
 from pydantic import Field, root_validator
 
@@ -8,14 +8,14 @@ from weaverbird.pipeline.types import ColumnName
 
 
 class FillnaStep(BaseStep):
-    name: Literal['fillna'] = 'fillna'
-    columns: List[ColumnName] = Field(min_items=1)
+    name: Literal["fillna"] = "fillna"
+    columns: list[ColumnName] = Field(min_items=1)
     value: Any
 
     @root_validator(pre=True)
     def handle_legacy_syntax(cls, values):
-        if 'column' in values:
-            values['columns'] = [values.pop('column')]
+        if "column" in values:
+            values["columns"] = [values.pop("column")]
         return values
 
 
